function RadarOctave
% by GDN
% uso ReadToTermination.m

pkg load instrument-control

if (exist('serial') ~= 3)
    disp('Serial: Unsupported')
else
    disp('Serial: Supported')
    
    % Abbiamo testato la presenza di Arduino sulla COM3 con
    %   [FID, MSG] = fopen ("COM3","r")
    % che ha restituito un FID >0; abbiamo poi chiuso la porta con fclose(FID)
        
    s1 = serial('COM3')
    pause(1);  % Wait a second as it takes some ports a while to wake up
    
    % Set the port parameters
    set(s1, 'baudrate', 9600);
    set(s1, 'bytesize', 8);
    set(s1, 'parity', 'n');
    set(s1, 'stopbits', 1);
    set(s1, 'timeout', 123); % 12.3 Seconds as an example here
    
    % Optional commands, these can be 'on' or 'off'
    %set(s1, 'requesttosend', 'on');     % Sets the RTS line
    %set(s1, 'dataterminalready', 'on'); % Sets the DTR line
    
    srl_flush(s1);   % per ripulire un po', ma non e' detto sia necessaria
    
    %Customize graph
    figure('units','normalized','outerposition',[0 0 1 1]);
    whitebg('black');

    %Draw Scale Data
    maxR = 100; % max 50 cm, oppure 100
    th = linspace(0, pi, 1000);
    R = 10 : 10 : maxR;
    for i = 1 : length(R);
        x = R(i)*cos(th);
        y = R(i)*sin(th);
        plot(x,y,'Color', [0.603922 , 0.803922 , 0.196078] ,'LineWidth',1);
        hold on;
    end
    %Draw Axis data
    x0 = [0 100 0 0 0 0 ];  x1 = [0 100 86.60 50 -50 -86.60]; y0 = [0 0 0 0 0 0]; y1 = [100 0 50 86.60 86.60 50];
    for i=1:length(x0);
        hold on;
        plot([x0(i),x1(i)],[y0(i),y1(i)] ,'Color', [0.603922 , 0.803922 , 0.196078],'LineWidth',2);
    end
    
    %Draw Sonar default data
    for i=1:180
        hold on;
        [x, y] = pol2cart(i*0.0174532925, maxR);
        h(i) = plot([0,x],[0,y],'g','LineWidth',1);
    end
    
    while(1)
        d = ReadToTermination(s1);
        disp(d), fflush(stdout);
        c = str2num(char(d));
        if length(c) == 2 && c(1) >= 1 && c(1) <= 180
            th = c(1); th = 180 - th;
 %           disp(th); fflush(stdout);
            r = c(2); if r > maxR, r = maxR; end
 %           disp(r); fflush(stdout);
            set(h(th),'color','r');
            [x0, y0] = pol2cart(th*0.0174532925, maxR);
            [x, y] = pol2cart(th*0.0174532925, r);
            set(h(th),'XData',[x0,x]);
            set(h(th),'YData',[y0,y]);
            m = plot([0,x0],[0,y0],'r','LineWidth',3);
            drawnow
            delete(m);
        end
    end  % while
    srl_close(s1);
    fprintf('\n')
end
end